function [f,LAST,f_1,f_2] = sigma_eps_concrete_mander (index_fib,eps,CLS,GEOM,section_type)


%INPUT -
%OUTPUT -


switch section_type
    case 'rectangular'
        B=GEOM.B;
        H=GEOM.H;
        hut=GEOM.hut;
        dsup=GEOM.dsup;
        dlat=GEOM.dlat;
    case 'circular'
        D=GEOM.D;
        d=GEOM.d;
end
dfib_G=GEOM.dfib_G(index_fib);

fco=CLS.fco;
epsco=CLS.epsco;
fcc=CLS.fcc;
epscc=CLS.epscc;
Esec=CLS.Esec;
r=CLS.r;
Eseco=CLS.Eseco;
ro=CLS.ro;
epscsp=CLS.epscsp;
fct=CLS.fct;
epsct=CLS.epsct;

% 1->core
% 2->cover

if eps<=epsct
    f_1=0;
    Etg_1=0;
    f_2=f_1;
    Etg_2=Etg_1;
    LAST(1)=3;
elseif eps<0
    f_1=fct/epsct*eps;
    Etg_1=fct/epsct;
    f_2=f_1;
    Etg_2=Etg_1;
    LAST(1)=2;
else
    
    x_1=eps/epscc;
    f_1=(fcc*x_1*r)/(r-1+x_1^r);
    Etg_1=Esec*r*(r-1)*(1-x_1^r)/(r-1+x_1^r)^2.0;

    if eps<=2*epsco
        x_2=eps/epsco;
        f_2=(fco*x_2*ro)/(ro-1+x_2^ro);
        Etg_2=Eseco*ro*(ro-1)*(1-x_2^ro)/(ro-1+x_2^ro)^2.0;
    elseif eps<=epscsp
        f_2epsco=(fco*2*ro)/(ro-1+2^ro);
        f_2=interp1([2*epsco epscsp],[f_2epsco 0],eps);
        Etg_2=(0-f_2epsco)/(epscsp-2*epsco);
    else
        f_2=0;
        Etg_2=0;
    end

    LAST(1)=1;

end



switch section_type
    case 'rectangular'
        dfib_sup=H/2-dfib_G;
        if ( dfib_sup<dsup || dfib_sup>hut )
            f=f_2;
            Etg=Etg_2;
        else
            B_1=B - 2*dlat;
            B_2=2*dlat;
            f=(f_1*B_1+f_2*B_2)/B;
            Etg=(Etg_1*B_1+Etg_2*B_2)/B;
        end
    case 'circular'
        dfib_sup=D/2-dfib_G;
        if ( dfib_sup<d || dfib_sup>(D-d) )
            f=f_1;
            Etg=Etg_1;
        else
            %calcolo larghezza corda del segmento circolare all'altezza del baricentro della fibra per cerchio esterno ed interno
            if dfib_sup<=D/2
                h_1=dfib_sup; %height_circular_segment (esterno)
                h_2=dfib_sup-d; %height_circular_segment (interno)
            else
                h_1=D-dfib_sup; %height_circular_segment (esterno)
                h_2=(D-dfib_sup)-d; %height_circular_segment (interno)
            end
            a_1=2*(h_1*(D-h_1))^0.5; %chord_length_circular_segment (esterno)
            a_2=2*(h_2*((D-2*d)-h_2))^0.5; %chord_length_circular_segment (interno)
            B_1=a_2;
            B_2=a_1-a_2;
            f=(f_1*B_1+f_2*B_2)/a_1;
            Etg=(Etg_1*B_1+Etg_2*B_2)/a_1;
        end
end



LAST(2)=eps;
LAST(3)=f;
LAST(4)=Etg;